#!/bin/bash
#
# source: http://avahi.org/download/avahi-0.6.30.tar.gz
#
# maintainer: (package seek a maintainer)
#

#------------------Set Some Variables

soft='avahi'
softversion='0.6.30'
packageversion='72.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.txz
rm -rf $dest

#------------------Set correct permissions

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --mandir=/usr/man \
  --disable-static \
  --disable-monodoc \
  --disable-autoipd \
  --enable-python-dbus \
  --enable-pygtk\
  --enable-glib \
  --enable-dbus \
  --enable-python \
  --enable-gtk \
  --enable-qt4 \
  --disable-qt3 \
  --enable-compat-howl \
  --enable-compat-libdns_sd \
  --with-dbus-sys=/etc/dbus-1/system.d \
  --with-avahi-user=daemon \
  --with-avahi-group=daemon \
  --with-avahi-priv-access-group=netdev \
  --with-distro=slackware

make -j6
make install DESTDIR=$dest

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

find $dest/usr/man -type f -exec gzip -9 {} \;
for i in $(find $dest/usr/man -type l); do ln -s $(readlink $i).gz $i.gz; rm $i; done

mv $dest/etc/rc.d/rc.avahidaemon $dest/etc/rc.d/rc.avahidaemon.new
mv $dest/etc/rc.d/rc.avahidnsconfd $dest/etc/rc.d/rc.avahidnsconfd.new
mv $dest/etc/avahi/avahi-daemon.conf $dest/etc/avahi/avahi-daemon.conf.new
mv $dest/etc/dbus-1/system.d/avahi-dbus.conf \
   $dest/etc/dbus-1/system.d/avahi-dbus.conf.new

#-------------------Prepare the documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a LICENSE docs/* $dest/usr/doc/$soft-$softversion

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

     |-----handy-ruler------------------------------------------------------|
avahi: avahi - A multicast unicast DNS-SD framework
avahi:
avahi: Avahi is an Implementation the DNS Service Discovery and Multicast 
avahi: DNS specifications for Zeroconf Computing. It uses D-BUS for 
avahi: communication between user applications and a system daemon. The 
avahi: daemon is used to coordinate application efforts in caching replies,
avahi: necessary to minimize the traffic imposed on networks. This kind of
avahi: technology  is already found  in  Apple MacOS X (branded Rendezvous
avahi: Bonjour and sometimes Zeroconf) and is very convenient.
avahi:
avahi:
EODESC

zcat $buildir/doinst.sh.gz > $dest/install/doinst.sh

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion
cp -a $buildir/doinst.sh.gz $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5